@@ -5,6 +5,10 @@ release_bullets <- function() { # nocov start
     "Run `goodpractice::gp()`",
     "Review [WORDLIST](https://docs.cran.dev/spelling#wordlist)",
     "Check if `# nolint` comments are still needed with recent lintr releases",
+    paste(
+      "Check if", file.path("man", "figures", "simulist_archi.png"),
+      "needs updating"
+    ),
     "All contributors to this release are acknowledged in some way"
   )
 } # nocov end
